package Bundle::Advent::Year2007;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2007 - Modules of the 2007 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2007 Perl Advent Calendar:
L<http://www.perladvent.org/2007/>.

    $ cpan Bundle::Advent::Year2007

=head1 CONTENTS

Data::ICal - L<Data::ICal|pod>, L<http://www.perladvent.org/2007/01/>

Parallel::Jobs - L<Parallel::Jobs|pod>, L<http://www.perladvent.org/2007/02/>

DBIx::Profile - L<DBIx::Profile|pod>, L<http://www.perladvent.org/2007/03/>

Test::Differences - L<Test::Differences|pod>, L<http://www.perladvent.org/2007/04/>

File::Which - L<File::Which|pod>, L<http://www.perladvent.org/2007/05/>

File::ReadBackwards - L<File::ReadBackwards|pod>, L<http://www.perladvent.org/2007/06/>

TimeDate - L<TimeDate|pod>, L<http://www.perladvent.org/2007/07/>

Math::Combinatorics - L<Math::Combinatorics|pod>, L<http://www.perladvent.org/2007/08/>

Sub::Versive - L<Sub::Versive|pod>, L<http://www.perladvent.org/2007/09/>

forks - L<forks|pod>, L<http://www.perladvent.org/2007/11/>

DateTime::TimeZone - L<DateTime::TimeZone|pod>, L<http://www.perladvent.org/2007/16/>

Pod::Simple::Subclassing - L<Pod::Simple::Subclassing|pod>, L<http://www.perladvent.org/2007/17/>

Acme::Curses:Marquee - L<Acme::Curses:Marquee|pod>, L<http://www.perladvent.org/2007/18/>

Perl5.10 - L<Perl5.10|pod>, L<http://www.perladvent.org/2007/19/>

B::Fathom - L<B::Fathom|pod>, L<http://www.perladvent.org/2007/23/>

Text::vCard - L<Text::vCard|pod>, L<http://www.perladvent.org/2007/24/>

Time::Out - L<Time::Out|pod>, L<http://www.perladvent.org/2007/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2007

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
