package Bundle::Advent::Year2000;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2000 - Modules of the 2000 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2000 Perl Advent Calendar:
L<http://www.perladvent.org/2000/>.

    $ cpan Bundle::Advent::Year2000

=head1 CONTENTS

Data::Dumper - L<Data::Dumper|pod>, L<http://www.perladvent.org/2000/01/>

LWP::Simple - L<LWP::Simple|pod>, L<http://www.perladvent.org/2000/02/>

POE::Component::IRC - L<POE::Component::IRC|pod>, L<http://www.perladvent.org/2000/03/>

Exporter - L<Exporter|pod>, L<http://www.perladvent.org/2000/04/>

Time::Local - L<Time::Local|pod>, L<http://www.perladvent.org/2000/05/>

Time::Object - L<Time::Object|pod>, L<http://www.perladvent.org/2000/06/>

Tie::Scalar::Timeout - L<Tie::Scalar::Timeout|pod>, L<http://www.perladvent.org/2000/07/>

Tie::HashDefaults - L<Tie::HashDefaults|pod>, L<http://www.perladvent.org/2000/08/>

Crypt::RC4 - L<Crypt::RC4|pod>, L<http://www.perladvent.org/2000/09/>

GD - L<GD|pod>, L<http://www.perladvent.org/2000/10/>

Image::Imlib2 - L<Image::Imlib2|pod>, L<http://www.perladvent.org/2000/11/>

File::Remote - L<File::Remote|pod>, L<http://www.perladvent.org/2000/12/>

XML::Grove - L<XML::Grove|pod>, L<http://www.perladvent.org/2000/14/>

Getopt::Long - L<Getopt::Long|pod>, L<http://www.perladvent.org/2000/15/>

File::Find - L<File::Find|pod>, L<http://www.perladvent.org/2000/16/>

DBI - L<DBI|pod>, L<http://www.perladvent.org/2000/17/>

Memoize - L<Memoize|pod>, L<http://www.perladvent.org/2000/18/>

Storable - L<Storable|pod>, L<http://www.perladvent.org/2000/19/>

Inline - L<Inline|pod>, L<http://www.perladvent.org/2000/20/>

Class::Virtual - L<Class::Virtual|pod>, L<http://www.perladvent.org/2000/21/>

Class::Multimethods - L<Class::Multimethods|pod>, L<http://www.perladvent.org/2000/22/>

Symbol::Approx::Sub - L<Symbol::Approx::Sub|pod>, L<http://www.perladvent.org/2000/23/>

Template - L<Template|pod>, L<http://www.perladvent.org/2000/24/>

Date::Christmas - L<Date::Christmas|pod>, L<http://www.perladvent.org/2000/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2000

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
