package Bundle::Advent::Year2002;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2002 - Modules of the 2002 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2002 Perl Advent Calendar:
L<http://www.perladvent.org/2002/>.

    $ cpan Bundle::Advent::Year2002

=head1 CONTENTS

URI::Find - L<URI::Find|pod>, L<http://www.perladvent.org/2002/01/>

IO::AtomicFile - L<IO::AtomicFile|pod>, L<http://www.perladvent.org/2002/02/>

DBD::SQLite - L<DBD::SQLite|pod>, L<http://www.perladvent.org/2002/03/>

Test::Builder - L<Test::Builder|pod>, L<http://www.perladvent.org/2002/04/>

Image::Size - L<Image::Size|pod>, L<http://www.perladvent.org/2002/05/>

Devel::Size - L<Devel::Size|pod>, L<http://www.perladvent.org/2002/06/>

File::MMagic - L<File::MMagic|pod>, L<http://www.perladvent.org/2002/07/>

XML::Handler::AxPoint - L<XML::Handler::AxPoint|pod>, L<http://www.perladvent.org/2002/08/>

XML::SAX - L<XML::SAX|pod>, L<http://www.perladvent.org/2002/09/>

Params::Validate - L<Params::Validate|pod>, L<http://www.perladvent.org/2002/10/>

File::Find::Rule - L<File::Find::Rule|pod>, L<http://www.perladvent.org/2002/11/>

Object::Realize::Later - L<Object::Realize::Later|pod>, L<http://www.perladvent.org/2002/12/>

Benchmark - L<Benchmark|pod>, L<http://www.perladvent.org/2002/13/>

Test::MockObject - L<Test::MockObject|pod>, L<http://www.perladvent.org/2002/14/>

YAML - L<YAML|pod>, L<http://www.perladvent.org/2002/15/>

WWW::Mechanize - L<WWW::Mechanize|pod>, L<http://www.perladvent.org/2002/16/>

Acme::Intraweb - L<Acme::Intraweb|pod>, L<http://www.perladvent.org/2002/17/>

CPANPLUS - L<CPANPLUS|pod>, L<http://www.perladvent.org/2002/18/>

Inline::TT - L<Inline::TT|pod>, L<http://www.perladvent.org/2002/19/>

Class::Data::Inheritable - L<Class::Data::Inheritable|pod>, L<http://www.perladvent.org/2002/20/>

Tie::File - L<Tie::File|pod>, L<http://www.perladvent.org/2002/21/>

XML::LibXML - L<XML::LibXML|pod>, L<http://www.perladvent.org/2002/22/>

Class::DBI - L<Class::DBI|pod>, L<http://www.perladvent.org/2002/23/>

Pixie - L<Pixie|pod>, L<http://www.perladvent.org/2002/24/>

Devel::DProf - L<Devel::DProf|pod>, L<http://www.perladvent.org/2002/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2002

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
