package Bundle::Advent::Year2003;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2003 - Modules of the 2003 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2003 Perl Advent Calendar:
L<http://www.perladvent.org/2003/>.

    $ cpan Bundle::Advent::Year2003

=head1 CONTENTS

CGI::Untaint - L<CGI::Untaint|pod>, L<http://www.perladvent.org/2003/01/>

HTML::Entities - L<HTML::Entities|pod>, L<http://www.perladvent.org/2003/02/>

Hook::LexWrap - L<Hook::LexWrap|pod>, L<http://www.perladvent.org/2003/03/>

PPerl - L<PPerl|pod>, L<http://www.perladvent.org/2003/04/>

Template::Extract - L<Template::Extract|pod>, L<http://www.perladvent.org/2003/05/>

Mail::SpamAssassin - L<Mail::SpamAssassin|pod>, L<http://www.perladvent.org/2003/06/>

Attribute::Handlers - L<Attribute::Handlers|pod>, L<http://www.perladvent.org/2003/07/>

CGI::Application - L<CGI::Application|pod>, L<http://www.perladvent.org/2003/08/>

Data::Dimensions - L<Data::Dimensions|pod>, L<http://www.perladvent.org/2003/09/>

Test::Inline - L<Test::Inline|pod>, L<http://www.perladvent.org/2003/10/>

File::chdir - L<File::chdir|pod>, L<http://www.perladvent.org/2003/11/>

Class::ISA - L<Class::ISA|pod>, L<http://www.perladvent.org/2003/12/>

only - L<only|pod>, L<http://www.perladvent.org/2003/13/>

Date::Parse - L<Date::Parse|pod>, L<http://www.perladvent.org/2003/14/>

Text::Glob - L<Text::Glob|pod>, L<http://www.perladvent.org/2003/15/>

Math::BigInt - L<Math::BigInt|pod>, L<http://www.perladvent.org/2003/16/>

diagnostics - L<diagnostics|pod>, L<http://www.perladvent.org/2003/17/>

PDF::Reuse - L<PDF::Reuse|pod>, L<http://www.perladvent.org/2003/18/>

Acme::Code::FreedomFighter - L<Acme::Code::FreedomFighter|pod>, L<http://www.perladvent.org/2003/19/>

Regex::Common (sic) - L<Regex::Common (sic)|pod>, L<http://www.perladvent.org/2003/20/>

Inline::Java - L<Inline::Java|pod>, L<http://www.perladvent.org/2003/21/>

LWP::Simple - L<LWP::Simple|pod>, L<http://www.perladvent.org/2003/22/>

Data::Structure::Util - L<Data::Structure::Util|pod>, L<http://www.perladvent.org/2003/24/>

PAR - L<PAR|pod>, L<http://www.perladvent.org/2003/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2003

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
