package Bundle::Advent::Year2004;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2004 - Modules of the 2004 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2004 Perl Advent Calendar:
L<http://www.perladvent.org/2004/>.

    $ cpan Bundle::Advent::Year2004

=head1 CONTENTS

DateTime - L<DateTime|pod>, L<http://www.perladvent.org/2004/01/>

Term::ANSIColor - L<Term::ANSIColor|pod>, L<http://www.perladvent.org/2004/02/>

Class::Accessor::Chained - L<Class::Accessor::Chained|pod>, L<http://www.perladvent.org/2004/03/>

String::ShellQuote - L<String::ShellQuote|pod>, L<http://www.perladvent.org/2004/04/>

CPAN::Mini - L<CPAN::Mini|pod>, L<http://www.perladvent.org/2004/05/>

Module::Pluggable - L<Module::Pluggable|pod>, L<http://www.perladvent.org/2004/06/>

Term::ProgressBar - L<Term::ProgressBar|pod>, L<http://www.perladvent.org/2004/07/>

Data::Dumper::Simple - L<Data::Dumper::Simple|pod>, L<http://www.perladvent.org/2004/08/>

Proc::Daemon - L<Proc::Daemon|pod>, L<http://www.perladvent.org/2004/09/>

Data::UUID - L<Data::UUID|pod>, L<http://www.perladvent.org/2004/10/>

Encode - L<Encode|pod>, L<http://www.perladvent.org/2004/11/>

Text::Unidecode - L<Text::Unidecode|pod>, L<http://www.perladvent.org/2004/12/>

Devel::Trace - L<Devel::Trace|pod>, L<http://www.perladvent.org/2004/13/>

SQL::Abstract - L<SQL::Abstract|pod>, L<http://www.perladvent.org/2004/14/>

Archive::Extract - L<Archive::Extract|pod>, L<http://www.perladvent.org/2004/15/>

Cache::Cache - L<Cache::Cache|pod>, L<http://www.perladvent.org/2004/16/>

Mac::Glue - L<Mac::Glue|pod>, L<http://www.perladvent.org/2004/17/>

Acme::Drunk - L<Acme::Drunk|pod>, L<http://www.perladvent.org/2004/18/>

Filesys::Virtual - L<Filesys::Virtual|pod>, L<http://www.perladvent.org/2004/20/>

Sys::Hostname - L<Sys::Hostname|pod>, L<http://www.perladvent.org/2004/21/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2004

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
