package Bundle::Advent::Year2005;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2005 - Modules of the 2005 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2005 Perl Advent Calendar:
L<http://www.perladvent.org/2005/>.

    $ cpan Bundle::Advent::Year2005

=head1 CONTENTS

HTML::Parser - L<HTML::Parser|pod>, L<http://www.perladvent.org/2005/05/>

LWP::Simple - L<LWP::Simple|pod>, L<http://www.perladvent.org/2005/05/>

Lingua::EN::Numbers::Ordinate - L<Lingua::EN::Numbers::Ordinate|pod>, L<http://www.perladvent.org/2005/05/>

Perl::Tidy - L<Perl::Tidy|pod>, L<http://www.perladvent.org/2005/05/>

Text::Table - L<Text::Table|pod>, L<http://www.perladvent.org/2005/05/>

Interpolation - L<Interpolation|pod>, L<http://www.perladvent.org/2005/06/>

spod5 - L<spod5|pod>, L<http://www.perladvent.org/2005/07/>

bignum - L<bignum|pod>, L<http://www.perladvent.org/2005/08/>

CGI::Ajax - L<CGI::Ajax|pod>, L<http://www.perladvent.org/2005/09/>

PPT - L<PPT|pod>, L<http://www.perladvent.org/2005/10/>

Perl6::Junction - L<Perl6::Junction|pod>, L<http://www.perladvent.org/2005/11/>

re - L<re|pod>, L<http://www.perladvent.org/2005/12/>

Regexp::Keep - L<Regexp::Keep|pod>, L<http://www.perladvent.org/2005/13/>

HTML::Lint - L<HTML::Lint|pod>, L<http://www.perladvent.org/2005/14/>

Data::COW - L<Data::COW|pod>, L<http://www.perladvent.org/2005/15/>

XML::RSS::SimpleGen - L<XML::RSS::SimpleGen|pod>, L<http://www.perladvent.org/2005/16/>

Acme::POE::Knee - L<Acme::POE::Knee|pod>, L<http://www.perladvent.org/2005/17/>

Regexp::Assemble - L<Regexp::Assemble|pod>, L<http://www.perladvent.org/2005/18/>

Test::Perl::Critic - L<Test::Perl::Critic|pod>, L<http://www.perladvent.org/2005/19/>

Perl::Compare - L<Perl::Compare|pod>, L<http://www.perladvent.org/2005/20/>

Want - L<Want|pod>, L<http://www.perladvent.org/2005/21/>

Module::CoreList - L<Module::CoreList|pod>, L<http://www.perladvent.org/2005/22/>

Sort::Maker - L<Sort::Maker|pod>, L<http://www.perladvent.org/2005/23/>

enum - L<enum|pod>, L<http://www.perladvent.org/2005/24/>

enum::hash - L<enum::hash|pod>, L<http://www.perladvent.org/2005/24/>

Text::FIGlet - L<Text::FIGlet|pod>, L<http://www.perladvent.org/2005/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2005

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
