package Bundle::Advent::Year2001;

our $VERSION = '0.01';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2001 - Modules of the 2001 Perl Advent Calendar

=head1 VERSION

Version 0.01

=head1 SYNOPSIS

Bundle for the modules featured in the 2001 Perl Advent Calendar:
L<http://www.perladvent.org/2001/>.

    $ cpan Bundle::Advent::Year2001

=head1 CONTENTS

Mail::Audit - L<Mail::Audit|pod>, L<http://www.perladvent.org/2001/01/>

Mail::ListDetector - L<Mail::ListDetector|pod>, L<http://www.perladvent.org/2001/02/>

Tie::DBI - L<Tie::DBI|pod>, L<http://www.perladvent.org/2001/03/>

File::Spec - L<File::Spec|pod>, L<http://www.perladvent.org/2001/04/>

XML::XPath - L<XML::XPath|pod>, L<http://www.perladvent.org/2001/05/>

Acme::Pony - L<Acme::Pony|pod>, L<http://www.perladvent.org/2001/06/>

Scalar::Util - L<Scalar::Util|pod>, L<http://www.perladvent.org/2001/07/>

List::Util - L<List::Util|pod>, L<http://www.perladvent.org/2001/08/>

GraphViz - L<GraphViz|pod>, L<http://www.perladvent.org/2001/09/>

Test::More - L<Test::More|pod>, L<http://www.perladvent.org/2001/10/>

POE - L<POE|pod>, L<http://www.perladvent.org/2001/11/>

POE::Component::Client::HTTP - L<POE::Component::Client::HTTP|pod>, L<http://www.perladvent.org/2001/12/>

Crypt::Solitaire - L<Crypt::Solitaire|pod>, L<http://www.perladvent.org/2001/13/>

Spreadsheet::WriteExcel - L<Spreadsheet::WriteExcel|pod>, L<http://www.perladvent.org/2001/14/>

Pod::Coverage - L<Pod::Coverage|pod>, L<http://www.perladvent.org/2001/15/>

Tie::Hash::Cannabinol - L<Tie::Hash::Cannabinol|pod>, L<http://www.perladvent.org/2001/16/>

Attribute::TieClasses - L<Attribute::TieClasses|pod>, L<http://www.perladvent.org/2001/17/>

Attribute::Overload - L<Attribute::Overload|pod>, L<http://www.perladvent.org/2001/18/>

Class::MethodMaker - L<Class::MethodMaker|pod>, L<http://www.perladvent.org/2001/19/>

ExtUtils::ModuleMaker - L<ExtUtils::ModuleMaker|pod>, L<http://www.perladvent.org/2001/20/>

Exporter::Simple - L<Exporter::Simple|pod>, L<http://www.perladvent.org/2001/21/>

Text::Autoformat - L<Text::Autoformat|pod>, L<http://www.perladvent.org/2001/22/>

Inline::Files - L<Inline::Files|pod>, L<http://www.perladvent.org/2001/23/>

Quantum::Superpositions - L<Quantum::Superpositions|pod>, L<http://www.perladvent.org/2001/24/>

Parse::RecDescent - L<Parse::RecDescent|pod>, L<http://www.perladvent.org/2001/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2001

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
